#
# spec file for package opmsg
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opmsg
Version:        1.78s
Release:        1.15
Summary:        File encryption, sign and verify utility
License:        GPL-3.0-or-later
Group:          Productivity/Security
URL:            https://github.com/stealth/opmsg
Source0:        https://github.com/stealth/opmsg/archive/rel-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
#BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)

%description
opmsg is a replacement for gpg which can encrypt/sign/verify your mails or
create/verify detached signatures of local files. Even though the opmsg
output looks similar, the concept is entirely different.

* Perfect Forward Secrecy (PFS) by means of ECDH or DH Kex.
* Native EC or RSA fallback if no (EC)DH keys left.
* Signing messages is mandatory.
* OTR-like deniable signatures if demanded.
* Support for 1:1 key bindings to auto-select source key per
  destination.
* Adds the possibility to (re-)route messages different from mail
  address to defeat meta data collection.
* Key format suitable for easy use with QR codes.
* Optional cross-domain ECDH Kex.

%prep
%setup -q -n %{name}-rel-%{version}

%build
pushd src
%make_build all contrib

%install
pushd src
mkdir -p %{buildroot}/%{_bindir}
install %{name} %{buildroot}/%{_bindir}/%{name}
install opmux %{buildroot}/%{_bindir}/opmux
install opcoin %{buildroot}/%{_bindir}/opcoin
#mkdir -p %{buildroot}/%{_mandir}/man1
#help2man ./%{name} --no-info --output %{buildroot}/%{_mandir}/man1/%{name}.1

%files
%license LICENSE
%doc README.md sample.config GPL3
%{_bindir}/%{name}
%{_bindir}/opmux
%{_bindir}/opcoin
#%{_mandir}/man1/%{name}*

%changelog
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to to 1.78s:
  - opmsg: allow to pass --confdir and --burn via opmux to opmsg
  - opmsg: add RAND_load_file() return check also in main().
* Mon Nov 13 2017 astieger@suse.com
- opmsg 1.77s:
  * opmsg: correct error msg handling for libcrypto error queue
  * opmsg: speeding up keystore load by introducing load flags
  * opmsg: dont generate Kex keys in null crypto/signing case
  * opmsg: allow to selfsign generated personas, so peer can also
  - -decrypt it and check sig
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Thu Feb 23 2017 meissner@suse.com
- updated to 1.75s:
- updated to 1.74s:
  - opmsg: only one DH session key
* Tue May 24 2016 astieger@suse.com
- update to 1.70s:
  * adding opmux wrapper
  * KDF version 2 is default for peers with opmsg >= 1.60
* Wed Dec  9 2015 astieger@suse.com
- update to 1.65s:
  * opmsg: implementing deniable personas
  * opmsg: allow multiple recipients for encryption/decryption (Cc)
  * opmsg: handle mutt calling with multiple recipients (Cc)
  * opmsg: more verbose output for Cc messages
* Mon Nov  9 2015 astieger@suse.com
- update to 1.61s:
  * opmsg: re-adding RAND_load_file() to gen_dh_key(). Only for
    safety (already called inside main) but in case keystore is
    used externally.
* Mon Sep 14 2015 astieger@suse.com
- update to 1.60s:
  * added native encryption for EC personas, similar to --rsa
    override
  * dont need to construct EC_GROUP if using
    EC_KEY_new_by_curve_name() which obtains all necessary parameters
  * adjusting I/O handling for opmsg-stick/ropmsg
  * oflush vs. eflush
  * some code cleanup and additional error checks
  * implementing deniable messages
  * generalizing kex key generation (ECDH, DH), adding possibility
    to track peer-key usage
  * Adding version 2 KDF and making peer-isolation configurable
* Tue Sep  8 2015 astieger@suse.com
- initial package
